pub struct Etag { /* private fields */ }Expand description
Etag and If-None-Match header handler
Trillium handler that provides an outbound etag header
after other handlers have been run, and if the request includes an
if-none-match
header, compares these values and sends a
304 not modified status,
omitting the response body.
Streamed bodies
Note that this handler does not currently provide an etag trailer for streamed bodies, but may do so in the future.
Strong vs weak comparison
Etags can be compared using a strong method or a weak
method. By default, this handler allows weak comparison. To change
this setting, construct your handler with Etag::new().strong().
See etag::EntityTag
for further documentation.
Implementations